@@ -10,9 +10,12 @@ use Log::Log4perl qw(get_logger);
 use Farly::Director;
 use Farly::Object;
 
-our $VERSION = '0.20';
 
-Log::Log4perl::init( '/etc/farly/logging.conf' );
+our $VERSION = '0.21';
+
+our ( $volume, $dir, $file ) = File::Spec->splitpath( $INC{'Farly.pm'} );
+Log::Log4perl::init( $volume . $dir . 'Farly/Log/Farly.conf' );
+
 
 sub new {
     my ( $class, $container ) = @_;
